You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by ba...@apache.org on 2006/10/11 22:25:16 UTC

svn commit: r462928 - /myfaces/core/branches/jsf12/impl/src/main/java/org/apache/myfaces/taglib/core/ParamTag.java

Author: baranda
Date: Wed Oct 11 13:25:15 2006
New Revision: 462928

URL: http://svn.apache.org/viewvc?view=rev&rev=462928
Log:
MYFACES-1456 (Implement JSR-252 core tag: ParamTag)

Modified:
    myfaces/core/branches/jsf12/impl/src/main/java/org/apache/myfaces/taglib/core/ParamTag.java

Modified: myfaces/core/branches/jsf12/impl/src/main/java/org/apache/myfaces/taglib/core/ParamTag.java
URL: http://svn.apache.org/viewvc/myfaces/core/branches/jsf12/impl/src/main/java/org/apache/myfaces/taglib/core/ParamTag.java?view=diff&rev=462928&r1=462927&r2=462928
==============================================================================
--- myfaces/core/branches/jsf12/impl/src/main/java/org/apache/myfaces/taglib/core/ParamTag.java (original)
+++ myfaces/core/branches/jsf12/impl/src/main/java/org/apache/myfaces/taglib/core/ParamTag.java Wed Oct 11 13:25:15 2006
@@ -1,5 +1,5 @@
 /*
- * Copyright 2004 The Apache Software Foundation.
+ * Copyright 2004-2006 The Apache Software Foundation.
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,17 +15,19 @@
  */
 package org.apache.myfaces.taglib.core;
 
-import org.apache.myfaces.shared_impl.taglib.UIComponentTagBase;
+import org.apache.myfaces.shared_impl.taglib.UIComponentELTagBase;
 
 import javax.faces.component.UIComponent;
+import javax.el.ValueExpression;
 
 /**
  * DOCUMENT ME!
  * @author Manfred Geiler (latest modification by $Author$)
+ * @author Bruno Aranda (JSR-252)
  * @version $Revision$ $Date$
  */
 public class ParamTag
-    extends UIComponentTagBase
+    extends UIComponentELTagBase
 {
     public String getComponentType()
     {
@@ -37,11 +39,10 @@
         return null;
     }
 
     // UIComponent attributes --> already implemented in UIComponentTagBase
 
     // UIParameter attributes
-    // value already implemented in UIComponentTagBase
-    private String _name;
+    private ValueExpression _name;
 
     protected void setProperties(UIComponent component)
     {
@@ -50,7 +51,7 @@
         setStringProperty(component, "name", _name);
     }
 
-    public void setName(String name)
+    public void setName(ValueExpression name)
     {
         _name = name;
     }
@@ -37,11 +39,10 @@
     }
 
-    // UIComponent attributes --> already implemented in UIComponentTagBase
+    // UIComponent attributes --> already implemented in UIComponentELTagBase
 
     // UIParameter attributes